//
//  UseCard.h
//  CardSDKDemo
//
//  Created by test on 2021/7/27.
//

#import <Foundation/Foundation.h>

NS_ASSUME_NONNULL_BEGIN

@interface UseCard : NSObject
/** 创建单例,调用其他方法请先创建单例 */
+(instancetype)shareSingleton;
/**
 接口身份初始化,必须先调用这个接口

 @param sid 锁掌柜开发者账号的 Account SID
 @param token 锁掌柜开发者账号的 Auth Token
 */
-(void)registerSid:(NSString *)sid token:(NSString *)token;


/**
 获取发卡器MAC地址
 
 @param communityNo 集群编号  锁掌柜获取
 */

-(void)getMacWithCommunityNo:(NSString *)communityNo resultBlock:(void (^)(NSString *mac,NSString * error))resultBlock;


/**
 签发卡片
 
 @param communityNo 集群编号  锁掌柜获取
 @param buildNo 楼栋编号  锁掌柜的楼栋编号
 @param floorNo  楼层编号  锁掌柜的楼层编号
 @param roomNo 房间编号   锁掌柜的房间编号
 @param creatorPassword 用户密码
 @param mac 发卡器mac地址
 @param creatorMobile 手机号，此手机号用户应与应用程序用户相同(邮箱和手机号二选一必填)
 @param creatorEmail 邮箱，此邮箱用户应与应用程序用户相同(邮箱和手机号二选一必填)
 @param creatorAreaCode 应用程序手机号前面的区号（对应 creatorMobile，前面不加符号）
 @param opentype 开门方式，0：单开（默认），1：常开，门锁类型为QRBLOCK/QRMLOCK/QRALOCK时有效。
 @param owner 持有者（当签发 QRN和已连接QR盒子的锁类型的卡片时，此参数必填。）
 @param ownerGender 持有者性别，0：女，1：男（当签发 QRN和已连接QR盒子的锁类型的卡片时，此参数必填。）
 @param ownerAreaCode 持有者手机区号（前面不加符号）
 @param ownerMobile 持有者手机号码（不包括区号。当签发 QRN和已连接QR盒子的锁类型的卡片时，此参数必填，此手机号存在时会自动查询持卡人姓名，并忽略 owner 参数值；否则将为此手机号注册名称为 owner 的持卡人）
 @param resultBlock 签发返回信息 如果error为nil则签发成功，否则失败
 */
-(void)makeCardWithCommunityNo:(NSString *)communityNo buildNo:(NSString *)buildNo floorNo:(NSString *)floorNo roomNo:(NSString *)roomNo creatorPassword:(NSString *)creatorPassword mac:(NSString *)mac creatorMobile:(NSString *)creatorMobile creatorEmail:(NSString *)creatorEmail creatorAreaCode:(NSString *)creatorAreaCode opentype:(NSString *)opentype owner:(NSString *)owner ownerGender:(NSString *)ownerGender ownerAreaCode:(NSString *)ownerAreaCode ownerMobile:(NSString *)ownerMobile resultBlock:(void (^)(NSString * error))resultBlock;


/**
 读取卡片信息
 
 @param communityNo 集群编号  锁掌柜获取
 @param creatorPassword 用户密码
 @param mac 发卡器mac地址
 @param creatorMobile 手机号，此手机号用户应与应用程序用户相同(邮箱和手机号二选一必填)
 @param creatorEmail 邮箱，此邮箱用户应与应用程序用户相同(邮箱和手机号二选一必填)
 @param creatorAreaCode 应用程序手机号前面的区号（对应 creatorMobile，前面不加符号）
 @param operateCardType 操作的感应卡类型。在锁掌柜web端房间管理中可以查看锁类型，当锁类型是RFLOCK-V9时传2，锁类型为QRLOCK时传3，其余的锁类型统统传为4（其余锁类型包括QRALOCK、QRBLOCK、QRMLOCK、QRNLOCK-WIFI）
 @param resultBlock 读取返回信息 如果error为nil则读取成功，否则失败
 */
-(void)readCardWithCommunityNo:(NSString *)communityNo creatorPassword:(NSString *)creatorPassword mac:(NSString *)mac creatorMobile:(NSString *)creatorMobile creatorEmail:(NSString *)creatorEmail creatorAreaCode:(NSString *)creatorAreaCode operateCardType:(NSString *)operateCardType resultBlock:(void (^)(NSString * error,NSDictionary *infoDict))resultBlock;



/**
 注销房卡，调用此方法前应先调用读取卡信息方法
 
 @param resultBlock 读取返回信息 如果error为nil则读取成功，否则失败
 */
-(void)cancelCardWithResultBlock:(void (^)(NSString * error))resultBlock;
@end

NS_ASSUME_NONNULL_END
